@extends('peek::layouts.app')

@section('submenu')
    @include('peek::commands.partials.submenu')
@endsection

@section('content')
    <div class="px-12 pt-8">
        <h1 class="text-xl mb-1 font-bold text-green-500">{{ $commandName }}</h1>
        <p class="mb-4">{{ $currentCommand->getDescription() }}</p>

        <form action="{{ route('peek.commands.store') }}" method="POST">
            {!! csrf_field() !!}
            <input type="hidden" name="command" value="{{ $commandName }}" />
            @if (count($currentCommand->getDefinition()->getArguments()) > 0)
                <h3 class="mb-3 font-bold text-gray-600">Arguments</h3>
                <div class="flex flex-wrap items-center">
                    @foreach ($currentCommand->getDefinition()->getArguments() as $argument)
                        <div class="flex flex-col mb-4 mr-8">
                            <label class="mb-1">
                                <span class="font-bold">{{ $argument->getName() }} {{ $argument->isRequired() ? '' : '(optional)' }}</span>
                                <input
                                    name="parameters[{{ $argument->getName() }}]"
                                    value="{{ $argument->getDefault() }}"
                                    {{ $argument->isRequired() ? 'required' : '' }}
                                    class="px-4 py-2 border border-gray-300 block mt-1 rounded dark-mode:bg-gray-800 dark-mode:border-gray-700"
                                />
                            </label>
                            <span class="text-gray-600 italic">{{ $argument->getDescription() }}</span>
                        </div>
                    @endforeach
                </div>
            @endif
            @if (count($currentCommand->getDefinition()->getOptions()) > 0)
                <h3 class="mb-3 font-bold text-gray-600">Options</h3>
                <div class="mb-4 flex flex-wrap items-center">
                    @foreach ($currentCommand->getDefinition()->getOptions() as $option)
                        <div class="flex flex-col mb-4 mr-8">
                            <label class="mb-1">
                                @if ($option->acceptValue())
                                    <span class="font-bold">{{ $option->getName() }} {{ $option->isValueRequired() ? '' : '(optional)' }}</span>
                                    <input
                                        name="parameters[--{{ $option->getName() }}]"
                                        value="{{ $option->isArray() ? 'array' : $option->getDefault() }}"
                                        {{ $option->isValueRequired() ? 'required' : '' }}
                                        class="px-4 py-2 border border-gray-300 block mt-1 rounded dark-mode:bg-gray-800 dark-mode:border-gray-700"
                                    />
                                @else
                                    <span class="font-bold mr-1">{{ $option->getName() }}</span>
                                    <input type="checkbox" name="parameters[--{{ $option->getName() }}]" value="true" />
                                @endif
                            </label>
                            <span class="text-gray-600 italic">{{ $option->getDescription() }}</span>
                        </div>
                    @endforeach
                </div>
            @endif

            <button class="bg-green-500 text-white px-2 py-1 rounded mb-2">
                Execute
            </button><br>
        </form>
        @if ($logs->count() > 0)
        <div class="mb-6">
            <h3 class="font-bold mb-6">Previous Runs</h3>
            <div class="flex flex-wrap justify-between">
                @foreach ($logs->values() as $index => $log)
                    <div class="flex mb-3">
                        <span class="font-bold p-3 rounded-l bg-gray-300 dark-mode:bg-gray-800">#{{ $index + 1 }}</span>
                        <a href="{{ route('peek.commands.files.show', [$commandName, $log->file]) }}" class="p-3 bg-gray-200 dark-mode:bg-gray-700">
                            {{ $log->lastModified->format('jS M Y H:i:s') }}
                        </a>
                        <form action="{{ route('peek.commands.files.delete', [$commandName, $log->file]) }}" method="POST">
                            <input type="hidden" name="_method" value="delete" />
                            {!! csrf_field() !!}
                            <button class="p-3 rounded-r bg-red-500 text-white mr-3">
                                Delete
                            </button>
                        </form>
                    </div>
                @endforeach
            </div>
        </div>

        <h4><span class="font-bold">Ran at:</span> <span class="pl-2 text-gray-500">{{ $selectedLog->lastModified->format('jS M Y h:i') }}</span></h4>
        <pre class="border border-grey-100 dark-mode:border-gray-700 rounded-lg p-8 overflow-x-scroll">
{!! $selectedLog->html !!}
        </pre>
        @else
            <h2 class="text-xl">This command has never been ran before.</h2>
        @endif
    </div>
@endsection
