<?php

namespace Drp\Peek\Environment;

use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class Writer
{
    /** @var string */
    private $file;

    /** @var string */
    private $disk;

    public function __construct(string $file = '.env', string $disk = 'peek:root')
    {
        $this->file = $file;
        $this->disk = $disk;
    }

    public function put(array $config, BannedVariables $banned): void
    {
        $config = collect($config);
        $envFile = Storage::disk($this->disk)->get($this->file);

        $envFile = $this->insertVariables($config, $envFile);
        $envFile = $this->updateVariables($config, $envFile);
        $envFile = $this->removeVariable($config, $envFile, $banned);

        Storage::disk($this->disk)->put($this->file, $envFile);
    }

    private function wrapIfSpaces(string $value): string
    {
        if (Str::startsWith($value, '"')) {
            return $value;
        }

        if (Str::contains($value, ' ')) {
            return '"' . $value . '"';
        }

        return $value;
    }

    private function removeVariable(Collection $config, string $envFile, BannedVariables $banned): string
    {
        $matches = [];
        preg_match_all('/([A-Z_]+)=/', $envFile, $matches);
        foreach ($matches[1] as $match) {
            if ($banned->isBanned($match)) {
                continue;
            }

            if (array_key_exists($match, $config->toArray())) {
                continue;
            }

            $envFile = preg_replace("/$match=.*\n?/", '', $envFile);
        }

        return $envFile;
    }

    private function insertVariables(Collection $config, string $envFile): string
    {
        $newFields = $config->keys()->filter(function ($key) use ($envFile) {
            return count(preg_grep("/$key=/", [$envFile])) === 0;
        });
        $newVariables = array_intersect_key($config->toArray(), $newFields->flip()->toArray());

        foreach ($newVariables as $name => $value) {
            $envFile .= PHP_EOL . $name . '=' . $value;
        }

        return $envFile;
    }

    private function updateVariables(Collection $config, string $envFile): string
    {
        foreach ($config as $name => $value) {
            $envFile = preg_replace(
                "/^$name=.*/m",
                "$name=" . $this->wrapIfSpaces((string) $value),
                $envFile
            );
        }

        return $envFile;
    }
}
